@@ -1,6 +1,6 @@
 /* Inspired from sbitmap_a_or_b_and_c_cg function in sbitmap.c.  */
 /* { dg-do run } */
-/* { dg-options "-O2 -fmodulo-sched -fmodulo-sched-allow-regmoves" } */
+/* { dg-options "-O2 -fmodulo-sched -fmodulo-sched-allow-regmoves -fdump-rtl-sms" } */
 
 extern void abort (void);
 
@@ -9,6 +9,7 @@ int b[5] = { 0, 1, 0, 1, 0 };
 int c[5] = { 0, 0, 1, 1, 0 };
 int dst[5] = { 0, 0, 0, 0, 0 };
 
+__attribute__ ((noinline))
 void
 foo (int size, int *ap, int *bp, int *cp, int *dstp)
 {
@@ -33,3 +34,6 @@ main ()
   return 0;
 }
 
+/* { dg-final { scan-rtl-dump-times "SMS succeeded" 1 "sms" { target spu-*-* powerpc*-*-* } } } */
+/* { dg-final { cleanup-rtl-dump "sms" } } */
+
